Shi-Tomasi corner detector {#tutorial_good_features_to_track}
==========================

Goal
----

In this tutorial you will learn how to:

-   Use the function @ref cv::goodFeaturesToTrack to detect corners using the Shi-Tomasi method.

Theory
------

Code
----

This tutorial code's is shown lines below. You can also download it from
[here](https://github.com/opencv/opencv/tree/master/samples/cpp/tutorial_code/TrackingMotion/goodFeaturesToTrack_Demo.cpp)
@include samples/cpp/tutorial_code/TrackingMotion/goodFeaturesToTrack_Demo.cpp

Explanation
-----------

Result
------

![](images/Feature_Detection_Result_a.jpg)
